<?php

$LANG = array(

'L_MENU'													=> 'Meniu',
'L_UNKNOWN_ERROR'											=> 'Eroare necunoscută',
'L_CONFIRM_DELETE'											=> 'Confirmați ștergerea ?',
'L_SAVE_FILE'												=> 'Salvați fișierul',
'L_SAVE_FILE_SUCCESSFULLY'									=> 'Fișier salvat cu succes',
'L_SAVE_FILE_ERROR'											=> 'Salvarea fișierului de eroare',
'L_DELETE'													=> 'Şterge',
'L_DELETE_FILE' 				    						=> 'Ștergeți fișier',
'L_DELETE_FOLDER'				   							=> 'Ștergeți dosar',
'L_SAVE_SUCCESSFUL'											=> 'Înregistrarea a fost efectuata cu succes',
'L_SAVE_ERR'												=> 'Eroare la înregistrare ',
'L_NO_ENTRY'												=> 'Acces refuzat',
'L_ERR_USER_EMPTY'											=> 'Vă rugăm să introduceţi un nume de utilizator',
'L_ERR_PASSWORD_EMPTY'										=> 'Vă rugăm să introduceţi o parolă',
'L_ERR_PASSWORD_EMPTY_CONFIRMATION'							=> 'Verificaţi veridicitatea parolei',
'L_ERR_INVALID_EMAIL'										=> 'Adresa de e-mail nevalidă',
'L_ERR_INVALID_SITE'										=> 'Adresa site gresita',
'L_ERR_INVALID_ARTICLE_IDENT'								=> 'ID articol gresit !',
'L_DEFAULT_NEW_CATEGORY_URL'								=> 'categorie-noua',
'L_DEFAULT_NEW_STATIC_URL'									=> 'pagina-noua',
'L_DEFAULT_NEW_ARTICLE_URL'									=> 'articol-nou',
'L_ARTICLE_SAVE_SUCCESSFUL'									=> 'Articol creat cu succes',
'L_ARTICLE_MODIFY_SUCCESSFUL'								=> 'Articol actualizat cu succes',
'L_ARTICLE_DELETE_SUCCESSFUL'								=> 'Eliminarea a decurs cu succes',
'L_ARTICLE_SAVE_ERR'										=> 'Eroare la salvarea articolului',
'L_ARTICLE_DELETE_ERR'										=> 'A apărut o eroare în timpul eliminarii articolului',
'L_ERR_UNKNOWN_COMMENT'										=> 'Comentariul cerut nu exista, sau nu e accesibil',
'L_COMMENT_SAVE_SUCCESSFUL'									=> 'Comentariu modificat cu succes',
'L_COMMENT_UPDATE_ERR'										=> 'Eroare la actualizarea comentariului',
'L_COMMENT_DELETE_SUCCESSFUL'								=> 'Eliminarea a decurs cu succes',
'L_COMMENT_DELETE_ERR'										=> 'A apărut o eroare la ştergere',
'L_COMMENT_VALIDATE_SUCCESSFUL'								=> 'Validarea a decurs cu succes',
'L_COMMENT_VALIDATE_ERR'									=> 'A apărut o eroare în timpul validării',
'L_COMMENT_MODERATE_SUCCESSFUL'								=> 'Moderarea a decurs cu succes',
'L_COMMENT_MODERATE_ERR'									=> 'A apărut o eroare la moderare',
'L_COMMENT_WRITTEN_BY'										=> 'Scris de',
'L_PLXMEDIAS_MEDIAS_FOLDER_ERR'								=> 'Imposibil de a crea un fişier media',
'L_PLXMEDIAS_ROOT'											=> 'radacina',
'L_PLXMEDIAS_NEW_FOLDER_ERR'								=> 'Nu poate fi creat directoriul',
'L_PLXMEDIAS_NEW_FOLDER_SUCCESSFUL'							=> 'Fişier creat cu succes',
'L_PLXMEDIAS_NEW_FOLDER_EXISTS'								=> 'Acest fişier există deja',
'L_PLXMEDIAS_DEL_FOLDER_ERR'								=> 'Eroare la ştergerea fişierului',
'L_PLXMEDIAS_DEL_FOLDER_SUCCESSFUL'							=> 'Fişier şters cu succes',
'L_PLXMEDIAS_WRONG_FILEFORMAT'								=> 'tipul de fişier nu este permis',
'L_PLXMEDIAS_WRONG_FILESIZE'								=> 'Dimensiunea fisierului espre prea mare ',
'L_PLXMEDIAS_UPLOAD_ERR'									=> 'Eroare în timp ce trimiterea unui fişier',
'L_PLXMEDIAS_UPLOAD_SUCCESSFUL'								=> 'Fişier trimis cu succes',
'L_PLXMEDIAS_UPLOADS_ERR'									=> 'Eroare în timp ce încărcarea fişierelor',
'L_PLXMEDIAS_UPLOADS_SUCCESSFUL'							=> 'FFişierele trimise cu succes',
'L_PLXMEDIAS_DELETE_FILES_SUCCESSFUL'						=> 'eliminat cu succes fişiere',
'L_PLXMEDIAS_DELETE_FILES_ERR'								=> 'Eroare la ştergerea unui fişier',
'L_PLXMEDIAS_DELETE_FILE_SUCCESSFUL'						=> 'Fişier şters cu succes',
'L_PLXMEDIAS_DELETE_FILE_ERR'								=> 'Eroare la ştergerea fişierului',
'L_PLXMEDIAS_MOVE_FILES_SUCCESSFUL'							=> 'Fişiere mutate cu succes',
'L_PLXMEDIAS_MOVE_FILE_SUCCESSFUL'							=> 'Fişier mutat cu succes',
'L_PLXMEDIAS_MOVE_FILES_ERR'								=> 'Eroare în timpul mutarii fişierelor',
'L_PLXMEDIAS_MOVE_FILE_ERR'									=> 'Eroare în timpul deplasarii fişierelor',
'L_PLXMEDIAS_MOVE_FOLDER'									=> 'Mută',
'L_PLXMEDIAS_RECREATE_THUMB_ERR'							=> 'Eroare în timp ce crearea miniatură',
'L_PLXMEDIAS_RECREATE_THUMBS_ERR'							=> 'Eroare la crearea miniatură',
'L_PLXMEDIAS_RECREATE_THUMB_SUCCESSFUL'						=> 'Miniatură creat cu succes',
'L_PLXMEDIAS_RECREATE_THUMBS_SUCCESSFUL'					=> 'Thumbnails creat cu succes',
'L_DEFAULT_NEW_ARTICLE_TITLE'								=> 'Articol Nou',
'L_ERR_INVALID_PUBLISHING_DATE'								=> 'Data publicării gresita.',
'L_ERR_UNKNOWN_ARTICLE'										=> 'Articolul solicitat nu exista sau a fost sters !',
'L_ERR_FORBIDDEN_ARTICLE'									=> 'Nu ai drepturile de acces la articolul dat !',
'L_BACK_TO_ARTICLES'										=> 'Înapoi la lista de articole',
'L_ARTICLE_EDITING'											=> 'Modificarea articolului',
'L_ARTICLE_TITLE'											=> 'Titlu',
'L_ARTICLE_LIST_AUTHORS'									=> 'Autor',
'L_HEADLINE_FIELD'											=> 'Headline (opţional)',
'L_CONTENT_FIELD'											=> 'Conţinut',
'L_LINK_FIELD'												=> 'Link la articol',
'L_LINK_ACCESS'												=> 'Du-te la articol',
'L_LINK_VIEW'												=> 'vedea',
'L_ARTICLE_STATUS'											=> 'Status',
'L_DRAFT'													=> 'Schiţă',
'L_PUBLISHED'												=> 'Publicat',
'L_AWAITING'												=> 'Până la validare',
'L_ARTICLE_DATE'											=> 'Data publicării',
'L_NOW'														=> 'acum',
'L_ARTICLE_CATEGORIES'										=> 'Categoriile articolului',
'L_CATEGORY_HOME_PAGE'										=> 'Home',
'L_NEW_CATEGORY'											=> 'Categorie nouă',
'L_ARTICLE_TAGS_FIELD'										=> 'Cuvinte cheie',
'L_ARTICLE_TAGS_FIELD_TITLE'								=> 'Separaţi cuvintele cheie prin virgulă',
'L_ARTICLE_TOGGLER_TITLE'									=> 'Listă de cuvinte cheie',
'L_NO_TAG'													=> 'Fara tag-uri',
'L_ALLOW_COMMENTS'											=> 'Permiteţi Comentarii',
'L_ARTICLE_URL_FIELD'										=> 'Url',
'L_ARTICLE_URL_FIELD_TITLE'									=> 'Article Url Field Title',
'L_ARTICLE_TEMPLATE_FIELD'									=> 'Template',
'L_ARTICLE_MANAGE_COMMENTS'									=> 'Administreaza Comentariile',
'L_ARTICLE_MANAGE_COMMENTS_TITLE'							=> 'Gestionarea comentariilor din acest articol',
'L_ARTICLE_NEW_COMMENT'										=> 'Scrie un comentariu',
'L_ARTICLE_NEW_COMMENT_TITLE'								=> 'Scrie un comentariu la acest articol',
'L_ARTICLE_DELETE_CONFIRM'									=> 'Ştergeţi acest articol ?',
'L_ARTICLE_PREVIEW_BUTTON'									=> 'Preview',
'L_ARTICLE_DRAFT_BUTTON'									=> 'Salvează schiţa',
'L_ARTICLE_PUBLISHING_BUTTON'								=> 'Publică',
'L_ARTICLE_MODERATE_BUTTON'									=> 'Supune aprobării',
'L_ARTICLE_OFFLINE_BUTTON'									=> 'Offline',
'L_ARTICLE_UPDATE_BUTTON'									=> 'Salvează',
'L_CATEGORY_ADD_BUTTON'										=> 'Adaugă',
'L_ARTICLE_META_DESCRIPTION'								=> 'Meta tag-ul de conţinut "descriere" (opţional)',
'L_ARTICLE_META_KEYWORDS'									=> 'Meta tag-ul "Cuvinte cheie" (opţional)',
'L_ARTICLE_TITLE_HTMLTAG'									=> 'Conţinutul tag-ul titlu (opţional)',
'L_ARTICLE_CHAPO_HIDE'										=> 'ascunde',
'L_ARTICLE_CHAPO_DISPLAY'									=> 'afişa',
'L_ARTICLE'													=> 'articol',
'L_ARTICLE_ID'												=> 'ID',
'L_AUTH_PAGE_TITLE'											=> 'Pagina de autentificare',
'L_LOGOUT_SUCCESSFUL'										=> 'Vati deconectat cu succes',
'L_LOGIN_PAGE'												=> 'Conectare in zona de administrare ',
'L_AUTH_LOGIN_FIELD'										=> 'Username',
'L_AUTH_PASSWORD_FIELD'										=> 'Parola',
'L_SUBMIT_BUTTON'											=> 'OK',
'L_ERR_WRONG_PASSWORD'										=> 'Username sau parola incorecta',
'L_POWERED_BY'												=> 'Realizat de <a href="http://www.pluxml.org">PluXml</a>',
'L_CAT_TITLE'												=> 'Crearea şi editarea categoriei',
'L_CAT_LIST_ID'												=> 'Id',
'L_CAT_LIST_ACTIVE'											=> 'Activ',
'L_CAT_LIST_NAME'											=> 'Nume categorie',
'L_CAT_LIST_URL'											=> 'Url',
'L_CAT_LIST_SORT'											=> 'Sortare articole',
'L_CAT_LIST_BYPAGE'											=> 'Categorii pe pagina',
'L_CAT_LIST_ORDER'											=> 'Pentru',
'L_CAT_LIST_MENU'											=> 'Meniu',
'L_CATEGORY'												=> 'Categorie',
'L_DISPLAY'													=> 'Afişează',
'L_HIDE'													=> 'Ascunde',
'L_OPTIONS'													=> 'Opţiuni',
'L_FOR_SELECTION'											=> 'Alegeţi obţiunea...',
'L_CAT_APPLY_BUTTON'										=> 'Modifică lista de categorii',
'L_CAT_UNKNOWN'												=> 'Categorie necunoscuta',
'L_EDITCAT_PAGE_TITLE'										=> 'Editarea categoriei',
'L_EDITCAT_DESCRIPTION'										=> 'Descrierea',
'L_EDITCAT_DISPLAY_HOMEPAGE'								=> 'Afișare articole în această categorie pe pagina de start',
'L_EDITCAT_TEMPLATE'										=> 'Template',
'L_EDITCAT_BACK_TO_PAGE'									=> 'Înapoi la lista de categorii',
'L_EDITCAT_UPDATE'											=> 'Actualizeaza această categorie',
'L_EDITCAT_TITLE_HTMLTAG'									=> 'Conţinutul tag-ul titlu (opţional)',
'L_EDITCAT_META_DESCRIPTION'								=> 'Conţinutul tag-ului meta "descriere" pentru această categorie (opţional)',
'L_EDITCAT_META_KEYWORDS'									=> 'Conţinutul tag-ului meta "cuvinte-cheie" pentru această categorie (opţional)',
'L_COMMENT_ORPHAN'											=> 'nici un articol',
'L_COMMENT_ORPHAN_STATUS'									=> 'nu sunt vizibile (vă recomandăm să ştergeţi acest comentariu)',
'L_COMMENT_ARTICLE_LINKED'									=> 'Articole',
'L_COMMENT_ARTICLE_LINKED_TITLE'							=> 'Articolul anexat la acest comentariu',
'L_COMMENT_OFFLINE'											=> 'Offline',
'L_COMMENT_ONLINE'											=> 'Online',
'L_COMMENT_ONLINE_TITLE'									=> 'Lista de comentarii publicate',
'L_BACK_TO_ARTICLE_COMMENTS'								=> 'Înapoi la lista de comentarii la acest articol',
'L_BACK_TO_COMMENTS'										=> 'Înapoi la lista de comentarii',
'L_COMMENT_EDITING'											=> 'Editare comentariu',
'L_COMMENT_AUTHOR_FIELD'									=> 'Autor',
'L_COMMENT_TYPE_FIELD'										=> 'Tipul comentariului',
'L_COMMENT_DATE_FIELD'										=> 'Data şi ora publicării',
'L_COMMENT_IP_FIELD'										=> 'Ip',
'L_COMMENT_SITE_FIELD'										=> 'Site',
'L_COMMENT_EMAIL_FIELD'										=> 'E-mail',
'L_COMMENT_STATUS_FIELD'									=> 'Statut',
'L_COMMENT_LINKED_ARTICLE_FIELD'							=> 'Articolul ataşat',
'L_COMMENT_ARTICLE_FIELD'									=> 'Comentariu',
'L_COMMENT_DELETE_CONFIRM'									=> 'Ştergeţi acest comentariu ?',
'L_COMMENT_PUBLISH_BUTTON'									=> 'Validarea publicarea',
'L_COMMENT_OFFLINE_BUTTON'									=> 'Ia Offline',
'L_COMMENT_ANSWER_BUTTON'									=> 'Răspundeţi la acest comentariu',
'L_COMMENT_UPDATE_BUTTON'									=> 'Update',
'L_ERR_ANSWER_UNKNOWN_COMMENT'								=> 'Comentariul va încerca să răspundă la nu există sau nu-i  sunt mai !',
'L_ERR_ANSWER_OFFLINE_COMMENT'								=> 'comentariul este offline, nu  răspunsul !',
'L_ERR_COMMENT_UNKNOWN_ARTICLE'								=> 'Articolul solicitat nu exista, sau nu puteti scrie comentarii la acest articol !',
'L_ERR_CREATING_COMMENT'									=> 'A apărut o eroare în timpul creării comentariu',
'L_CREATING_COMMENT_SUCCESSFUL'								=> 'Comentariul a fost creat cu succes',
'L_CREATE_NEW_COMMENT'										=> 'Scrie un comentariu',
'L_COMMENT_SAVE_BUTTON'										=> 'Salva',
'L_ARTICLE_COMMENTS_LIST'									=> 'Comentarii la acest articol (mai nou de la vechi la cele mai)',
'L_COMMENT_ANSWER_TITLE'									=> 'Răspundeţi la acest comentariu',
'L_COMMENT_ANSWER'											=> 'Raspunde',
'L_COMMENT_NEW_COMMENT_TITLE'								=> 'Scrie un comentariu nou pentru acest articol',
'L_COMMENT_NEW_COMMENT'										=> 'Scrie un comentariu nou',
'L_COMMENTS_ARTICLE_SCOPE'									=> 'Articolul',
'L_COMMENTS_GLOBAL_SCOPE'									=> 'Întregul site-ului',
'L_COMMENTS_OFFLINE_LIST'									=> 'Lista de comentarii ce aşteaptă a fi aprobate ',
'L_COMMENTS_LIST_DATE'										=> 'Date',
'L_COMMENTS_LIST_AUTHOR'									=> 'Autor',
'L_COMMENTS_LIST_MESSAGE'									=> 'Mesaj',
'L_COMMENTS_LIST_ACTION'									=> 'Acţiune',
'L_COMMENT_EDIT'											=> 'Editare',
'L_COMMENT_EDIT_TITLE'										=> 'Editaţi acest comentariu',
'L_COMMENT_DELETE'											=> 'Şterge',
'L_COMMENT_OFFLINE_FEEDS_TITLE'								=> 'RSS comentarii offline',
'L_COMMENT_OFFLINE_FEEDS'									=> 'Comentarii Offline',
'L_COMMENT_ONLINE_FEEDS_TITLE'								=> 'Comentarii RSS online',
'L_COMMENT_ONLINE_FEEDS'									=> 'Comentarii Online',
'L_COMMENTS_PRIVATE_FEEDS'									=> 'Feed privat de comentarii',
'L_COMMENTS_ONLINE_LIST'									=> 'Lista de comentarii publicate',
'L_COMMENTS_ALL_LIST'										=> 'Lista comentarii',
'L_COMMENT_SET_ONLINE'										=> 'Ia Online',
'L_COMMENT_SET_OFFLINE'										=> 'Ia Offline',
'L_ARTICLES_FILTER_BUTTON'									=> 'Caută',
'L_CATEGORIES_TABLE'										=> 'Categorii',
'L_SPECIFIC_CATEGORIES_TABLE'								=> 'Locaţii specifice',
'L_ALL_ARTICLES_CATEGORIES_TABLE'							=> 'Toate elementele',
'L_ARTICLES_LIST'											=> 'Lista articolelor',
'L_ARTICLE_LIST_DATE'										=> 'Data',
'L_ARTICLE_LIST_TITLE'										=> 'Titlu',
'L_ARTICLE_LIST_CATEGORIES'									=> 'Categorii',
'L_ARTICLE_LIST_NBCOMS'										=> 'Statistici',
'L_ARTICLE_LIST_AUTHOR'										=> 'Autor',
'L_ARTICLE_LIST_ACTION'										=> 'Action',
'L_CATEGORY_HOME'											=> 'Home',
'L_CATEGORY_DRAFT'											=> 'Proiect de',
'L_ARTICLE_VIEW'											=> 'Vizualizează',
'L_ARTICLE_VIEW_TITLE'										=> 'Vezi acest articol pe site-ul',
'L_ARTICLE_EDIT'											=> 'Editează',
'L_ARTICLE_EDIT_TITLE'										=> 'Editează articolul dat',
'L_NEW_COMMENTS_TITLE'										=> 'Comentarii ce aşteaptă validarea',
'L_VALIDATED_COMMENTS_TITLE'								=> 'Comentarii postate',
'L_NO_ARTICLE'												=> 'Nu sunt articole',
'L_ARTICLES_SEARCH_BUTTON'									=> 'Căutare',
'L_ARTICLES_ALL_CATEGORIES'									=> 'Toate categoriile ...',
'L_ALL'														=> 'Toate',
'L_ALL_PUBLISHED'											=> 'Publicat',
'L_ALL_DRAFTS'												=> 'Schiţe',
'L_ALL_AWAITING_MODERATION'									=> 'Până la validare',
'L_MEDIAS_DELETE_FOLDER'									=> 'Ştergeţi Directoriu',
'L_MEDIAS_DELETE_FOLDER_CONFIRM'							=> 'Sunteti sigur ca doriti sa stergeţi directoriul şi conţinutul lui %s ?',
'L_MEDIAS_NO_FILE'											=> 'Nici un fişier',
'L_MEDIAS_FILENAME'											=> 'Filename',
'L_MEDIAS_ADD_FILE'											=> 'Adăugaţi fişiere',
'L_MEDIAS_BACK'												=> 'Back',
'L_MEDIAS_TITLE'											=> 'Management Media',
'L_MEDIAS_IMAGES'											=> 'Images',
'L_MEDIAS_DOCUMENTS'										=> 'Documente',
'L_MEDIAS_CREATE_FOLDER'									=> 'Crearea unui directoriu',
'L_MEDIAS_SUBMIT_FILE'										=> 'Trimite',
'L_MEDIAS_MAX_UPOLAD_FILE'									=> 'Dimensiunea maximă de fişier',
'L_MEDIAS_DIRECTORY'										=> 'Locaţie',
'L_MEDIAS_FOLDER'											=> 'Fişier',
'L_MEDIAS_NEW_FOLDER'										=> 'New Folder',
'L_MEDIAS_FILESIZE'											=> 'Dimensiunea',
'L_MEDIAS_DATE'												=> 'Data',
'L_MEDIAS_DIMENSIONS'										=> 'Dimensiuni',
'L_MEDIAS_RESIZE'											=> 'Redimensionarea Imagini',
'L_MEDIAS_RESIZE_NO'										=> 'Dimensiune original',
'L_MEDIAS_THUMBS'											=> 'A crea thumbnails',
'L_MEDIAS_THUMBS_NONE'										=> 'Nu thumbnail',
'L_MEDIAS_MODIFY'											=> 'Editare',
'L_MEDIAS_THUMB'											=> 'Thumbnail',
'L_MEDIAS_EXTENSION'										=> 'Extensie',
'L_MEDIAS_ADD'												=> 'Adaugă',
'L_MEDIAS_ALIGNMENT'										=> 'Aliniere',
'L_MEDIAS_ALIGN_NONE'										=> 'Nu',
'L_MEDIAS_ALIGN_LEFT'										=> 'Stânga',
'L_MEDIAS_ALIGN_CENTER'										=> 'Centru',
'L_MEDIAS_ALIGN_RIGHT'										=> 'Dreapta',
'L_MEDIAS_RECREATE_THUMB'									=> 'Recreează miniatură',
'L_SORT_ASCENDING_DATE'										=> 'data crescator',
'L_SORT_DESCENDING_DATE'									=> 'descendentă Data',
'L_SORT_ALPHABETICAL'										=> 'alfabetic',
'L_OK'														=> 'Ok',
'L_YES'														=> 'Da',
'L_NO'														=> 'Nu',
'L_NONE1'													=> 'nu',
'L_NONE2'													=> 'nimic',
'L_CONFIG_VIEW_FIELD'										=> 'Optiuni de afisare',
'L_CONFIG_VIEW_SKIN_SELECT'									=> 'Alege tema',
'L_CONFIG_VIEW_FILES_EDIT_TITLE'							=> 'Editaţi fişierele tema',
'L_CONFIG_VIEW_FILES_EDIT'									=> 'Editaţi fişierele tema',
'L_CONFIG_VIEW_SORT'										=> 'Sortare articole',
'L_CONFIG_VIEW_BYPAGE'										=> 'Numărul de  articole afisate pe pagina',
'L_CONFIG_VIEW_BYPAGE_ARCHIVES'								=> 'Numărul de  elemente afişate pe pagină în arhivă',
'L_CONFIG_VIEW_BYPAGE_ADMIN'								=> 'Numărul de  elemente afişate pe pagină în administraţie',
'L_CONFIG_VIEW_SORT_COMS'									=> 'Sortare comentarii',
'L_CONFIG_VIEW_BYPAGE_ADMIN_COMS'							=> 'Numărul de comentarii pe pagină în admin',
'L_CONFIG_VIEW_IMAGES'										=> 'Dimensiune imagine (latime x inaltime)',
'L_CONFIG_VIEW_THUMBS'										=> 'Thumbnail dimensiuni (latime x inaltime)',
'L_CONFIG_VIEW_HOMESTATIC'									=> 'Utilizaţi o pagină statică ca Home-page',
'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'							=> 'Atenţie, această pagină este inactivă',
'L_CONFIG_VIEW_PLUXML_RESSOURCES'							=> 'Descarcă alte teme <a href="http://ressources.pluxml.org">ressources.pluxml.org</a>.',
'L_CONFIG_VIEW_BYPAGE_FEEDS'								=> 'Numărul de articole  şi comentarii postate pe fluxul Rss',
'L_CONFIG_VIEW_FEEDS_HEADLINE'								=> 'Vezi Headerul în articolele RSS',
'L_CONFIG_VIEW_FEEDS_HEADLINE_HELP'							=> 'Dacă headerul este gol, conţinutul este afişat',
'L_CONFIG_VIEW_FEEDS_FOOTER'								=> 'Text se adaugă şi o semnătură în partea de jos a fiecare articole feed RSS',
'L_CONFIG_VIEW_UPDATE'										=> 'Editare Opţiuni  afişare',
'L_CONFIG_VIEW_DISPLAY_EMPTY_CAT'							=> 'Afişarea categorii fără articolul',
'L_CONFIG_HOMETEMPLATE'										=> 'Format din pagina de start',
'L_CONFIG_ADVANCED_DESC'									=> 'Avansate de configurare',
'L_CONFIG_ADVANCED_URL_REWRITE'								=> 'Permite rescrierea url-uri',
'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'						=> 'Atenţie într-un fişier. Htaccess este deja prezent la rădăcina PluXml dumneavoastră. Prin activarea rescrierea dosarul \ url va fi modificat',
'L_CONFIG_ADVANCED_GZIP'									=> 'Activeaza compresia GZIP',
'L_CONFIG_ADVANCED_GZIP_HELP'								=> 'Comprimă paginile pentru a salva de lăţime de bandă, însă acest lucru poate creşte sarcina procesorului',
'L_CONFIG_ADVANCED_CAPCHA'									=> 'Activeaza capcha anti-spam',
'L_CONFIG_ADVANCED_ADMIN_KEY'								=> 'Cheie de administrare (URL-uri private)',
'L_CONFIG_ADVANCED_KEY_HELP'								=> 'Clar acest domeniu pentru a regenera cheie',
'L_CONFIG_ADVANCED_USERFOLDERS'								=> 'Folosind medias dosar pentru fiecare utilizator diferite',
'L_HELP_SLASH_END'											=> 'Nu uita slash de final',
'L_CONFIG_ADVANCED_MEDIAS_FOLDER'							=> 'Locul de amplasare Media (director)',
'L_CONFIG_ADVANCED_ARTS_FOLDER'								=> 'Locul de amplasare de elemente (dosar)',
'L_CONFIG_ADVANCED_COMS_FOLDER'								=> 'Locul de amplasare Review (dosar)',
'L_CONFIG_ADVANCED_STATS_FOLDER'							=> 'Locul de amplasare de pagini statice (dosar)',
'L_CONFIG_ADVANCED_THEMES_FOLDER'							=> 'Locul de amplasare de subiecte (dosar)',
'L_CONFIG_ADVANCED_PLUGINS_FOLDER'							=> 'Locul de amplasare a plugin-uri (dosar)',
'L_CONFIG_ADVANCED_CONFIG_FOLDER'							=> 'Locul de fişiere de configurare (dosar)',
'L_CONFIG_ADVANCED_UPDATE'									=> 'Editare configuraţie avansată',
'L_CONFIG_CUSTOM_CSSADMIN_PATH'								=> 'Locația și numele de fișier css personalizat buna administrare (opțional)',
'L_CONFIG_BASE_CONFIG_TITLE'								=> 'Configurarea bazei',
'L_CONFIG_BASE_SITE_TITLE'									=> 'Denumirea sitului',
'L_CONFIG_BASE_SITE_SLOGAN'									=> 'Descriere sitului',
'L_CONFIG_BASE_URL_HELP'									=> 'Nu uita slash de final',
'L_CONFIG_BASE_DEFAULT_LANG'								=> 'Limba',
'L_CONFIG_BASE_TIMEZONE'									=> 'Time Zone',
'L_CONFIG_BASE_ALLOW_COMMENTS'								=> 'Permiteţi comentariile',
'L_CONFIG_BASE_MODERATE_COMMENTS'							=> 'Moderează comentariile',
'L_CONFIG_BASE_MODERATE_ARTICLES'							=> 'Articole moderată pentru Editor profile şi Distribuitor',
'L_CONFIG_BASE_UPDATE'										=> 'Schimba configuraţia de bază',
'L_CONFIG_META_DESCRIPTION'									=> 'Conţinutul tag-ul meta "descriere" a site-ului (opţional)',
'L_CONFIG_META_KEYWORDS'									=> 'Conţinut de meta tags "cuvinte cheie" Site-ul (opţional)',
'L_CONFIG_EDITTPL_ERROR_NOTHEME'							=> 'Aceasta temă nu există!',
'L_CONFIG_EDITTPL_TITLE'									=> 'Editare Tematica',
'L_CONFIG_EDITTPL_SELECT_FILE'								=> 'Selectaţi fişierul pentru a edita :',
'L_CONFIG_EDITTPL_LOAD'										=> 'Sarcină',
'L_CONFIG_INFOS_TITLE'										=> 'Informaţii privind PluXml',
'L_CONFIG_INFOS_DESCRIPTION'								=> 'Informaţiile pe care le furniza informaţii cu privire la modul PluXml dumneavoastră şi poate  dovedi util pentru depanare.',
'L_CONFIG_INFOS_NB_CATS'									=> 'Numărul de categorii :',
'L_CONFIG_INFOS_NB_STATICS'									=> 'Numărul de pagini statice :',
'L_CONFIG_INFOS_WRITER'										=> 'Editor-in Nume sesiune :',
'L_PLUXML_CHECK_VERSION'									=> 'Verificarea numărului de versiune pe site-ul oficial PluXml PluXml.org',
'L_PLUXML_UPDATE_UNAVAILABLE'								=> 'Imposibil de a verifica pentru updates ca allow_url_fopen este dezactivat pe acest sistem',
'L_PLUXML_UPDATE_ERR'										=> 'Audit actualizare a eşuat pentru un motiv necunoscut',
'L_PLUXML_UPTODATE'											=> 'Sunteţi online folosind cea mai recentă versiune a PluXml',
'L_PLUXML_UPDATE_AVAILABLE'									=> 'O nouă versiune a PluXml este disponibilă! O puteţi descărca',
'L_CONFIG_USERS_TITLE'										=> 'Gestionarea utilizatorilor',
'L_CONFIG_USER'												=> 'Utilizator',
'L_CONFIG_USERS_ID'											=> 'Users Id',
'L_CONFIG_USERS_ACTIVE'										=> 'Activitate',
'L_CONFIG_USERS_ACTION'										=> 'Acţiune',
'L_CONFIG_USERS_NEW'										=> 'Utilizator nou',
'L_CONFIG_USERS_UPDATE'										=> 'Modifică lista de utilizatori',
'L_ERR_LOGIN_ALREADY_EXISTS'								=> 'Login ID deja utilizate',
'L_ERR_USERNAME_ALREADY_EXISTS'								=> 'Nume de utilizator deja în uz',
'L_ERR_CATEGORY_ALREADY_EXISTS'								=> 'Categorie nume deja utilizate',
'L_ERR_STATIC_ALREADY_EXISTS'								=> 'Aşa cum deja utilizate',
'L_BACK_TO_PLUGINS'											=> 'Back to Plugins',
'L_NO_PLUGIN'												=> 'Nr plugin',
'L_PLUGIN_NO_CONFIG'										=> 'Nu Plugin configurat',
'L_PLUGINS_CSS'												=> 'Css',
'L_PLUGINS_CSS_TITLE'										=> 'Edita codul CSS al plugin',
'L_CONTENT_FIELD_FRONTEND'									=> 'Site-ul de conținut fișier css',
'L_CONTENT_FIELD_BACKEND'									=> 'CSS administrator conținutul fișierului',
'L_PLUGINS_TITLE'											=> 'Gestiunea plugin-urilor',
'L_PLUGINS_VERSION'											=> 'Versiune',
'L_PLUGINS_AUTHOR'											=> 'Autor',
'L_PLUGINS_ACTIVATE'										=> 'Activează',
'L_PLUGINS_DEACTIVATE'										=> 'Dezactivaţi',
'L_PLUGINS_DELETE'											=> 'Şterge',
'L_PLUGINS_DELETE_ERROR'									=> 'O eroare a generat în timpul deplasării',
'L_PLUGINS_DELETE_SUCCESSFUL'								=> 'Ştergerea a decurs cu succes',
'L_PLUGINS_CONFIG'											=> 'Configurare',
'L_PLUGINS_CONFIG_TITLE'									=> 'Configurarea plugin-ului',
'L_PLUGINS_HELP'											=> 'Ajutor',
'L_PLUGINS_HELP_TITLE'										=> 'A vedea utilizarea plugin-ului',
'L_PLUGINS_REQUIREMENTS'									=> 'Cerinţe preliminare',
'L_PLUGINS_REQUIREMENTS_HELP'								=> 'Lista de plugin-uri prezente şi active pentru activaţie',
'L_PLUGINS_REQUIREMENTS_NONE'								=> 'Nu',
'L_PLUGINS_ALPHA_SORT'										=> 'Sortează în ordine alfabetică plugin-uri',
'L_PLUGINS_LOADING_SORT'									=> 'De încărcare pentru',
'L_PLUGINS_ACTION'											=> 'Acţiune',
'L_PLUGINS_APPLY_BUTTON'									=> 'Modificarea lista de plugin-uri',
'L_PLUGINS_ACTIVE_LIST'										=> 'Plugin-uri active',
'L_PLUGINS_INACTIVE_LIST'									=> 'Plugin-uri inactive',
'L_PROFIL_EDIT_TITLE'										=> 'Editează Profilul',
'L_PROFIL'													=> 'Profil',
'L_PROFIL_LOGIN'											=> 'Login',
'L_PROFIL_USER'												=> 'Username',
'L_PROFIL_MAIL'												=> 'Adresa de email',
'L_PROFIL_ADMIN_LANG'										=> 'Limba utilizată',
'L_PROFIL_INFOS'											=> 'Informaţii',
'L_PROFIL_UPDATE'											=> 'Editează-ţi profilul',
'L_PROFIL_CHANGE_PASSWORD'									=> 'Schimbarea parolei',
'L_PROFIL_PASSWORD'											=> 'Parola',
'L_PROFIL_CONFIRM_PASSWORD'									=> 'Confirmaţi parola',
'L_PROFIL_UPDATE_PASSWORD'									=> 'Schimbaţi parola',
'L_STATIC_BACK_TO_PAGE'										=> 'Înapoi la lista de pagini statice',
'L_STATIC_UNKNOWN_PAGE'										=> 'Această pagină statică  nu există sau nu este accesibila !',
'L_STATIC_TITLE'											=> 'Editează codul sursă a paginei statice',
'L_STATIC_VIEW_PAGE'										=> 'Vizualizează pagina',
'L_STATIC_ON_SITE'											=> 'pe site',
'L_STATIC_UPDATE'											=> 'Salvaţi această pagină statică',
'L_STATIC_TITLE_HTMLTAG'									=> 'Conţinutul tag-ul titlu (opţional)',
'L_STATIC_META_DESCRIPTION'									=> 'Conţinutul tag-ul meta "descriere" pentru această pagină statică (opţional)',
'L_STATIC_META_KEYWORDS'									=> 'Conţinutul meta tag "keywords " la această pagină statică (opţional)',
'L_STATICS_PAGE_TITLE'										=> 'Crearea şi publicarea paginei statice',
'L_STATICS_ID'												=> 'Identificator',
'L_STATICS_GROUP'											=> 'Grupa',
'L_STATICS_TITLE'											=> 'Titlu',
'L_STATICS_URL'												=> 'Url',
'L_STATICS_ACTIVE'											=> 'Activ',
'L_STATICS_ORDER'											=> 'Ordinea',
'L_STATICS_MENU'											=> 'Meniu',
'L_STATICS_ACTION'											=> 'Acţiune',
'L_STATICS_TEMPLATE_FIELD'									=> 'Tema',
'L_STATICS_PAGE_HOME'										=> 'Setaţi ca pagina de start',
'L_STATICS_HOME_PAGE'										=> 'Home',
'L_PAGE'													=> 'Pagină',
'L_VIEW'													=> 'Vizualizează',
'L_STATICS_SRC_TITLE'										=> 'Editează codul sursă a acestei pagini',
'L_STATICS_SRC'												=> 'Editare',
'L_STATICS_NEW_PAGE'										=> 'Pagină nouă',
'L_STATICS_UPDATE'											=> 'Modifică lista paginilor statice',
'L_PROFIL_ADMIN'											=> 'Administrator',
'L_PROFIL_MANAGER'											=> 'Manager',
'L_PROFIL_MODERATOR'										=> 'Moderator',
'L_PROFIL_EDITOR'											=> 'Editor',
'L_PROFIL_WRITER'											=> 'Autor',
'L_ADMIN'													=> '- Administrare',
'L_LOGIN'													=> 'Logat ca',
'L_ADMIN_LOGOUT'											=> 'Deconectare',
'L_ADMIN_LOGOUT_TITLE'										=> 'Log Out Admin',
'L_BACK_TO_SITE'											=> 'Back to',
'L_BACK_TO_SITE_TITLE'										=> 'Go Back',
'L_BACK_TO_BLOG'											=> 'Blog',
'L_BACK_TO_BLOG_TITLE'										=> 'Inapoi la blog',
'L_MENU_ARTICLES'											=> 'Articole',
'L_MENU_ARTICLES_TITLE'										=> 'Listează şi schimbă articolele',
'L_MENU_NEW_ARTICLES'										=> 'Articol Nou',
'L_MENU_NEW_ARTICLES_TITLE'									=> 'Articol Nou',
'L_MENU_STATICS_TITLE'										=> 'Listează şi editează paginile statice',
'L_MENU_STATICS'											=> 'Pagini statice',
'L_MENU_COMMENTS_TITLE'										=> 'Listează şi editează comentariile',
'L_MENU_COMMENTS'											=> 'Comentarii',
'L_MENU_MEDIAS_TITLE'										=> 'Încărcaţi şi modificaţi imaginile',
'L_MENU_MEDIAS'												=> 'Imagini',
'L_MENU_CATEGORIES_TITLE'									=> 'Crează,gestionează,editează categoriile',
'L_MENU_CATEGORIES'											=> 'Categorii',
'L_MENU_CONFIG_TITLE'										=> 'Configurarează PluXml',
'L_MENU_CONFIG'												=> 'Setări',
'L_MENU_PROFIL_TITLE'										=> 'Gestionează profilul',
'L_MENU_PROFIL'												=> 'Profil',
'L_WARNING_INSTALLATION_FILE'								=> 'Fişierul install.php încă se află în rădăcina  sit-ului <br /> PluXml. Din motive de securitate, se recomandă să-l ştergeţi.',
'L_USER_UNKNOWN'											=> 'Utilizator necunoscut',
'L_USER_LANG'												=> 'Limba utilizată ',
'L_USER_MAIL'												=> 'Adresa de email',
'L_USER_INFOS'												=> 'Informaţii',
'L_USER_UPDATE'												=> 'Actualizează acest utilizator',
'L_USER_PAGE_TITLE'											=> 'Opţiuni',
'L_USER_BACK_TO_PAGE'										=> 'Înapoi la lista de utilizatori',
'L_MENU_CONFIG_BASE_TITLE'									=> 'Schimbă configuraţia de bază',
'L_MENU_CONFIG_BASE'										=> 'Configuraţia de bază',
'L_MENU_CONFIG_VIEW_TITLE'									=> 'Editarea opţiunilor de afişare',
'L_MENU_CONFIG_VIEW'										=> 'Opţiuni \ Afişare',
'L_MENU_CONFIG_USERS_TITLE'									=> 'Gestionează conturile utilizatorilor',
'L_MENU_CONFIG_USERS'										=> 'Conturile utilizatorilor',
'L_MENU_CONFIG_ADVANCED_TITLE'								=> 'Editarea configuraţiei avansate',
'L_MENU_CONFIG_ADVANCED'									=> 'Configurarea Avansată',
'L_MENU_CONFIG_INFOS_TITLE'									=> 'Obţinerea de informaţii despre PluXml',
'L_MENU_CONFIG_INFOS'										=> 'Informaţii',
'L_MENU_CONFIG_PLUGINS_TITLE'								=> 'Administrează Plugin-uri',
'L_MENU_CONFIG_PLUGINS'										=> 'Plugin-uri',
'L_ERR_URL_ALREADY_EXISTS'									=> 'Url deja în uz. Vă rugăm să schimbați valoarea din câmpul \'Url\'',
);

?>
